"""
Create groups of processes from groups of structure to allow the creation of
archives with provenance


"""
from aiida import load_profile
from aiida.orm.utils import load_group
from aiida.common.exceptions import NotExistent
from aiida import orm

load_profile()

only_groups = ['AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate']
process_labels = ['VaspMultiStepRelaxWorkchain']
process_types = [orm.WorkChainNode]
exit_statuses = [0]

for group_id in range(26):
    try:
        struct_group = load_group(group_id)
    except Exception as e:
        print(e)
        continue

    if len(only_groups):
        if struct_group.pk not in only_groups and (struct_group.label not in
                                                   only_groups):
            print(f'skipping group <{struct_group.pk}> {struct_group.label}.')
            continue

    qb = orm.QueryBuilder()
    qb.append(orm.Group, filters={"id": struct_group.pk}, tag="struct_group")
    qb.append(orm.StructureData, with_group="struct_group", tag="structures")
    qb.append(process_types, with_outgoing="structures",
              filters={
                  "attributes.process_label": {"in": process_labels},
                  "attributes.process_state": "finished",
                  "attributes.exit_status": {"in": exit_statuses}
              }, tag='processes')
    print(f"Query found {qb.count()} matches.")
    processes = [row[0] for row in qb.all()]

    node_labels = set([n.label for n in processes])
    node_labels_str = f" with labels {node_labels}" if len(node_labels) else None

    proc_group_label = struct_group.label + '_processes'
    is_new_group = False
    try:
        load_group(proc_group_label)
    except NotExistent:
        is_new_group = True
        proc_group = orm.Group(proc_group_label)
        proc_group.description = ("Group containing {} processes{} that lead "
            "to structures in Group {}").format(process_labels, node_labels_str,
                                                struct_group.label)
        proc_group.store()

    proc_group.add_nodes(processes)
    print(("{} {} processes{} were added to{} group <{}> {} with description "
           "\'{}\'.").format(len(processes), process_labels, node_labels_str,
                             " new" if is_new_group else None,
                             proc_group.pk, proc_group.label,
                             proc_group.description))
    if not is_new_group:
        print("Group <{}> {} now contains {} nodes.".format(
        proc_group.pk, proc_group.label, proc_group.count()))

print('Done.')
