"""
Export loaxest-energy structures in CIF and
"""

from aiida import load_profile
from aiida.orm.utils import load_node

import project_utils as pu
from pyama.utils import sort_structure_by_frac_coord
import os

# Create dir

load_profile()

export_dir = '/home/cadarp02/aiida_projects/AsTe3/Te-based_sc-181_2022-06-01/structures/relaxed_free_cell_accurate_dftd3bj'
struct_group_name = 'AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj'
nb_of_structures = 50

# TODO create dir
try:
    os.makedirs(export_dir)
except FileExistsError as e:
    print(e)

sorted_struct_pks = pu.sort_structures_in_group_by_energy(group_or_name=struct_group_name)

for struct_index, struct_pk in enumerate(sorted_struct_pks):
    if struct_index >= nb_of_structures:
        print('{} strutcures have been exported. Exiting'.format(struct_index))
        break
    struct = load_node(struct_pk)
    pmg_struct = struct.get_pymatgen()
    # sort along b-axis
    pmg_struct = sort_structure_by_frac_coord(pmg_struct, axis=1)
    basename = 'lowest-E-{:03d}_{}_free-cell_pbe-dftd3bj'.format(struct_index,
                                                                 struct_pk)

    filename = os.path.join(export_dir, basename) + '.cif'
    pmg_struct.to(filename=filename, fmt='cif')
    print('Structure {} was exported as file {}'.format(struct_pk, filename))

    filename = os.path.join(export_dir, basename) + '.vasp'
    pmg_struct.to(filename=filename, fmt='poscar')
    print('Structure {} was exported as file {}'.format(struct_pk, filename))


