"""
Export loaxest-energy structures in CIF and
"""

from aiida import load_profile
from aiida.orm.utils import load_node, load_group
from aiida.orm import StructureData, Group, QueryBuilder

import project_utils as pu
from pyama.utils import sort_structure_by_frac_coord
import os
import numpy as np
import pandas as pd

load_profile()

groups_and_energies = [
    {"group_label": "AsTe3_Te-based_sc181_As-Te-configurations_no-opt",
     "energy key": "lowest_E_C",
     "max_nb_of_struct": 500,
     },
    {"group_label": "AsTe3_Te-based_sc181_relaxed_fixed_cell_rough",
     "max_nb_of_struct": 250,
     },
]

qb = QueryBuilder()
qb.append(Group, project=["label"], tag="groups")
qb.append(StructureData, with_group="groups", tag="structures", project=["*"])
struct_groups = [load_group(gl) for gl in set([row[0] for row in qb.all()])]

print('struct_groups:\n{}\n'.format([f'<{g.pk}>: {g.label}' for g in
                                     struct_groups]))

max_nb_of_struct = 50
energy_key = 'relaxed_energies'
for g in struct_groups:
    # loop on groups and select those containing structures
    print(100 * '-' + f'\nGroup <{g.pk}>{g.label}\n' + 100 * '-')
    if g.label in [ge["group_label"] for ge in groups_and_energies]:
        # DEBUGGING
        print('Skipping group')
        continue

        i = [ge["group_label"] for ge in groups_and_energies].index(g.label)
        if "energy key" in groups_and_energies[i].keys():
            energy_key = groups_and_energies[i]["energy key"]

        if "max_nb_of_struct" in groups_and_energies[i].keys():
            max_nb_of_struct = groups_and_energies[i]["max_nb_of_struct"]

    try:
        data_dict = pu.get_data_dicts_in_group(g)[0]
    except IndexError:
        print(f'No data_dict found in group <{g.pk}> {g.label}')
        continue

    sorted_indexes = np.argsort(data_dict[energy_key])
    if "relaxed_struct_pks" in data_dict.keys():
        sorted_struct_pks = [data_dict["relaxed_struct_pks"][i] for i in
                             sorted_indexes]
    try:
        sorted_struct_pks = [data_dict["initial_struct_pks"][i] for i in
                             sorted_indexes]
    except KeyError as e:
        print(f'Structures in group <{g.pk}>{g.label} could not be sorted by '
              f'energy: {e}')
        continue


    export_dir = os.path.join(os.getcwd(), 'structures', 'by_group',
                              '_'.join(g.label.split()))
    try:
        os.makedirs(export_dir)
    except FileExistsError as e:
        print(e)

    # Export data_dict as csv
    df = pd.DataFrame(data_dict.get_dict())
    try:
        df.sort_values([energy_key, "relaxed_struct_pks"], inplace=True)
    except Exception as e:
        print(f"Dataframe could not be sorted: {e}. Trying with initial_struct_pks.")
        df.sort_values([energy_key, "initial_struct_pks"], inplace=True)
    filename = os.path.join(export_dir, "structures_data.csv")
    df.to_csv(filename)
    print(f"Data_dict was exported as file {filename}")

    for struct_index, struct_pk in enumerate(sorted_struct_pks):
        if struct_index >= max_nb_of_struct:
            print('{} strutcures have been exported. Exiting'.format(struct_index))
            break
        struct = load_node(struct_pk)
        pmg_struct = struct.get_pymatgen()
        # sort along b-axis
        pmg_struct = sort_structure_by_frac_coord(pmg_struct, axis=1)
        basename = 'lowest-E-{:03d}_{}'.format(struct_index, struct_pk)

        filename = os.path.join(export_dir, basename) + '.cif'
        pmg_struct.to(filename=filename, fmt='cif')
        print('Structure {} was exported as file {}'.format(struct_pk, filename))

        filename = os.path.join(export_dir, basename) + '.vasp'
        pmg_struct.to(filename=filename, fmt='poscar')
        print('Structure {} was exported as file {}'.format(struct_pk, filename))

