""" Script generating Te-As configurations in Te-based supercells

Generation of multiple combinations of As/Te in a 1x8x1 supercell based
on metallic Te, with composition AsTe3, using the aiida-supercell plugin.

Ranking structures based on lowest-E_C As(3+)Te(0)/Te(2-) configurations
"""

from aiida import load_profile
import project_utils as pu

load_profile()

def main():
    """
    Main workfunction to explore As/Te disorder in Te-metal 1x8x1 supercell
    """
    TEST_MODE=False
    pu.print_versions()
    # Line below not needed: using the default name if test_mode is False
    # supercell_group_name='AsTe3_Te-based_sc181_As-Te-configurations_no-opt'
    group = pu.generate_Te_As_configurations(test_mode=TEST_MODE)
    pu.calculate_lowest_E_C(test_mode=TEST_MODE)

    pu.retrieve_and_store_lowest_E_C(test_mode=TEST_MODE,
                                     data_description=None, verbosity=2)

if __name__ == '__main__':
    main()

