#!/usr/local/miniconda/envs/aiida-1.6.8/bin/python3
"""
Plot final DFT energy after relaxation vs lowest Te(0)/Te(2-) E_C before opt

See detailed description in cli() function below
"""
from aiida import load_profile

import project_utils as pu
from matplotlib import pyplot as plt

load_profile()
plt.rcParams['svg.fonttype'] = 'none'

group_basename = 'AsTe3_Te-based_sc181_relaxed'
relax_settings = ['fixed_cell_rough', 'free_cell_accurate', 'fixed_cell_accurate']
data_basename = 'relaxed_data'
experimental_neutron_file = (r'/home/cadarp02/sujets-recherche/AsTe3/' +
    r'Diffraction/Neutron_AndreaPiarristeguy/261764_LAMPascii_Te65_429K')
experimental_neutron_title = 'Experiment, 429 K'
experimental_xrd_file = (r'/home/cadarp02/sujets-recherche/AsTe3/' +
    r'Diffraction/AsTe3_sintered_SPS_XRD_2021-01-04.dat')
experimental_xrd_title = 'Experiment (sintered - SPS)'

pdf_data = pu.get_experimental_xray_total_scattering()
experimental_pdf_file = pdf_data['file_name']
experimental_pdf_title = pdf_data['title']
pdf_r_max = 12.0
pdf_sigma = 0.15
verbosity=2

"""
# Plot Fixed-cell-rough relaxed energies vs lowest-E_C
fig1, ax1 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group=group_basename + '_' + relax_settings[0],
    y_data_group=group_basename + '_' + relax_settings[0],
    x_data_dict_label=data_basename + '_' + relax_settings[0],
    y_data_dict_label=data_basename + '_' + relax_settings[0],
    x_data_key='lowest_E_C', y_data_key='relaxed_energies',
    x_label='Lowest Te(0)/Te(2-)/As(3+)-configuration Coulomb energy (eV)',
    y_label='Relaxed with \'' + relax_settings[0] + '\' setting - energy (eV)',
    markersize=2,
    title='Lowest-E_C vs relaxed energies with setting \'{}\''.format(
          relax_settings[0]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.2, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.5, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    verbosity=verbosity
)
# Plot Free-cell-accurate relaxed energies vs lowest-E_C
fig2, ax2 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_As-Te-configurations_no-opt',
    y_data_group=group_basename + '_' + relax_settings[1],
    x_data_dict_label='lowest_E_C_data',
    y_data_dict_label=data_basename + '_' + relax_settings[1],
    x_data_key='lowest_E_C', y_data_key='relaxed_energies',
    x_label='Lowest Te(0)/Te(2-)/As(3+)-configuration Coulomb energy (eV)',
    y_label='Relaxed with \'' + relax_settings[1] + '\' setting - energy (eV)',
    markersize=2,
    title='Lowest-E_C vs relaxed energies with setting \'{}\''.format(
        relax_settings[1]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    total_pdf_r_max=pdf_r_max,
    verbosity=verbosity
)

# Plot Free-cell-accurate vs Fixed-cell-rough maximum forces
fig3, ax3 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group=group_basename + '_' + relax_settings[0],
    y_data_group=group_basename + '_' + relax_settings[1],
    x_data_dict_label=data_basename + '_' + relax_settings[0],
    y_data_dict_label=data_basename + '_' + relax_settings[1],
    x_data_key='maximum_forces', y_data_key='maximum_forces',
    x_label=relax_settings[0] + ' - maximum force (eV/\u212B)',
    y_label=relax_settings[1] + ' - maximum force (eV/\u212B)',
    verbosity=1, markersize=2,
    title=('Maximum force after relaxation with settings \'{}\' ' +
           'and \'{}\'').format(relax_settings[0], relax_settings[1]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.5, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    total_pdf_r_max=pdf_r_max,
    verbosity=verbosity
)
"""
# Plot Free-cell-accurate vs Fixed-cell-rough energies
fig, ax = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group=group_basename + '_' + relax_settings[0],
    y_data_group=group_basename + '_' + relax_settings[1],
    x_data_dict_label=data_basename + '_' + relax_settings[0],
    y_data_dict_label=data_basename + '_' + relax_settings[1],
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label=relax_settings[0] + ' - energy (eV)',
    y_label=relax_settings[1] + ' - energy (eV)',
    markersize=2,
    title=('Energies after relaxation with settings \'{}\' ' +
           'and \'{}\'').format(relax_settings[0], relax_settings[1]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=pdf_sigma,
    total_pdf_r_max=pdf_r_max,
    verbosity=verbosity
)
"""
# Plot Refined-fixed-cell-accurate relaxed energies vs lowest-E_C
fig4, ax4 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_As-Te-configurations_no-opt',
    y_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    x_data_dict_label='lowest_E_C_data',
    y_data_dict_label='relaxed_data_fixed_cell_accurate',
    x_data_key='lowest_E_C', y_data_key='relaxed_energies',
    x_label='Lowest Te(0)/Te(2-)/As(3+)-configuration Coulomb energy (eV)',
    y_label='Relaxed with fixed-refined cell accurate setting - energy (eV)',
    markersize=2,
    title='Lowest-E_C vs relaxed energies with XRD-PDF-refined cell and setting \'{}\''.format(
        relax_settings[1]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    total_pdf_r_max=pdf_r_max,
    verbosity=verbosity
)

# Plot Refined-fixed-cell-accurate relaxed energies vs free-cell-accurate
fig5, ax5 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate',
    y_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    x_data_dict_label='relaxed_data_free_cell_accurate',
    y_data_dict_label='relaxed_data_fixed_cell_accurate',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with \'' + relax_settings[1] + '\' setting - energy (eV)',
    y_label='Relaxed with fixed-refined cell accurate setting - energy (eV)',
    markersize=2,
    title='Lowest-E_C vs relaxed energies with XRD-PDF-refined cell and setting \'{}\''.format(
        relax_settings[1]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    total_pdf_r_max=pdf_r_max,
    verbosity=verbosity
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Plot Refined-fixed-cell-accurate relaxed energies vs max forces
fig6, ax6 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    x_data_dict_label='relaxed_data_fixed_cell_accurate',
    x_data_key='relaxed_energies', y_data_key='maximum_forces',
    x_label='Relaxed with fixed-refined cell accurate setting - max. forces (eV/\u212B)',
    y_label='Relaxed with fixed-refined cell accurate setting - energy (eV)',
    markersize=2,
    title='Lowest-E_C vs relaxed energies with XRD-PDF-refined cell and setting \'{}\''.format(
        relax_settings[1]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    total_pdf_r_max=pdf_r_max,
    verbosity=verbosity
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Scatter plot Refined-fixed-cell-accurate relaxed energies vs free-cell-accurate
# with forces as color and sizes
fig7, ax7 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate',
    y_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    x_data_dict_label='relaxed_data_free_cell_accurate',
    y_data_dict_label='relaxed_data_fixed_cell_accurate',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with \'' + relax_settings[1] + '\' setting - energy (eV)',
    y_label='Relaxed with fixed-refined cell accurate setting - energy (eV)',
    scatter_size_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate',
    scatter_size_data_dict_label='relaxed_data_free_cell_accurate',
    scatter_size_data_key='maximum_forces',
    scatter_size_scaling=100,
    scatter_size_label='free-cell max.force (eV/\u212B)',
    scatter_color_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    scatter_color_data_dict_label='relaxed_data_fixed_cell_accurate',
    scatter_color_data_key='maximum_forces',
    scatter_color_label='fixed-refined cell max.force (eV/\u212B)',
    markersize=2,
    title='Lowest-E_C vs relaxed energies with XRD-PDF-refined cell and setting \'{}\''.format(
        relax_settings[1]),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.2,
    total_pdf_r_max=pdf_r_max,
    verbosity=verbosity
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Plot Refined-fixed-supercell relaxed energies vs refined-fixed-cell-accurate
fig8, ax8 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    x_data_dict_label='relaxed_data_fixed_cell_accurate',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with fixed-refined cell accurate setting - max. forces (eV/\u212B)',
    y_data_group='AsTe3_Te-based_sc181_sc614_relaxed_fixed_supercell_accurate',
    y_data_dict_label='relaxed_data_fixed_supercell_accurate',
    y_label='Relaxed with fixed-refined supercell cell accurate setting - energy (eV)',
    markersize=2,
    title='Refined-fixed-6x1x4 supercell vs refined-fixed-cell-accurate relaxed energies',
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Plot Refined-fixed-supercell relaxed energies vs refined-fixed-cell-accurate
fig9, ax9 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    x_data_dict_label='relaxed_data_fixed_cell_accurate',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with fixed-refined cell accurate setting - max. forces (eV/\u212B)',
    y_data_group='AsTe3_Te-based_sc181_sc413_relaxed_fixed_413_supercell_accurate',
    y_data_dict_label='relaxed_data_fixed_413_supercell_accurate',
    y_label='Relaxed with fixed-refined 4x1x3 supercell cell accurate setting - energy (eV)',
    markersize=2,
    title='Refined-fixed-4x1x3 supercell vs refined-fixed-cell-accurate relaxed energies',
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

fig10, ax10 = plt.subplots(1, 1)
mapping = {
    'no-VdW': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_novdw',
        'dict_label': 'relaxed_data_fixed_cell_accurate_novdw',
    },
    'DFT-D2': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
        'dict_label': 'relaxed_data_fixed_cell_accurate',
    },
    'DFT-D3(zero)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3z',
        'dict_label': 'relaxed_data_fixed_cell_accurate_dftd3z',
    },
    'DFT-D3(BJ)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3bj',
        'dict_label': 'relaxed_data_fixed_cell_accurate_dftd3bj',
    },
}
lgd = []
for vdw in mapping.keys():
    if vdw != 'no-VdW':
        _fig, _ax = pu.plot_relaxed_energies_from_data_Dicts(
            x_data_group=mapping['no-VdW']['group'],
            x_data_dict_label=mapping['no-VdW']['dict_label'],
            x_data_key='relaxed_energies', y_data_key='relaxed_energies',
            x_label='Fixed-refined-cell relaxation without VdW - energy (eV)',
            y_data_group=mapping[vdw]['group'],
            y_data_dict_label=mapping[vdw]['dict_label'],
            y_label='Fixed-refined-cell relaxation with {} - energy (eV)'.format(
                vdw),
            title='Refined-fixed-cell energies with and without {} vdw correction.'.format(
                vdw),
            nd_experimental_file=experimental_neutron_file,
            nd_experimental_title=experimental_neutron_title,
            nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
            xrd_experimental_file=experimental_xrd_file,
            xrd_experimental_title=experimental_xrd_title,
            xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
            total_pdf_experimental_file=experimental_pdf_file,
            total_pdf_experimental_title=experimental_pdf_title,
            total_pdf_sigma=0.1,
            verbosity=verbosity,
            show_nd=True, show_xrd=True, show_total_pdf=True,
        )

        lgd.append(vdw)
        ax10.plot(_ax.lines[0].get_xdata(),
                  _ax.lines[0].get_ydata() - min(_ax.lines[0].get_ydata()), 'o',
                  markersize=5, fillstyle='none')
ax10.set_xlabel(_ax.get_xlabel())
ax10.set_ylabel('E - min(E) with VdW correction (eV)')
ax10.set_title('Effect of Van der Waals corrections on\nbest fixed-refined-cell structure energies')
ax10.legend(lgd, bbox_to_anchor=(1.05, 1.0), loc='upper left')
fig10.tight_layout()

# Plot Refined-fixed-supercell relaxed energies vs
# refined-fixed-cell-accurate-dft-d3z
fig10, ax10 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
    x_data_dict_label='relaxed_data_fixed_cell_accurate',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with fixed-refined cell and DFT-D2 - energy (eV) - energy (eV)',
    y_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3z',
    y_data_dict_label='relaxed_data_fixed_cell_accurate_dftd3z',
    y_label='Relaxed with fixed-refined cell and DFT-D3(zero) - energy (eV)',
    markersize=2,
    title='Refined-fixed-cell relaxation with different vdw corrections\n - relaxed energies',
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Plot Refined-fixed-supercell relaxed energies vs
# refined-fixed-cell-accurate-dft-d3z
fig11, ax11 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3z',
    x_data_dict_label='relaxed_data_fixed_cell_accurate_dftd3z',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with fixed-refined cell and DFT-D3(O) - energy (eV)',
    y_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3bj',
    y_data_dict_label='relaxed_data_fixed_cell_accurate_dftd3bj',
    y_label='Relaxed with fixed-refined cell and DFT-D3(BJ) - energy (eV)',
    markersize=2,
    title='Refined-fixed-cell relaxation with different vdw corrections\n - relaxed energies',
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)
"""
# Plot Refined-fixed-supercell relaxed energies vs
# refined-fixed-cell-accurate-dft-d3z
fig12, ax12 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_novdw',
    x_data_dict_label='relaxed_data_fixed_cell_accurate_novdw',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with fixed-refined cell (no VdW) - energy (eV)',
    y_data_group='AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3bj',
    y_data_dict_label='relaxed_data_fixed_cell_accurate_dftd3bj',
    y_label='Relaxed with fixed-refined cell and DFT-D3(BJ) - energy (eV)',
    markersize=2,
    title='Refined-fixed-cell relaxation with different vdw corrections\n - relaxed energies',
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.1,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Scatter plot Refined-fixed-cell-accurate relaxed energies vs free-cell-accurate
# with forces as color and sizes
fig20, ax20 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_novdw',
    y_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj',
    x_data_dict_label='relaxed_data_free_cell_accurate_novdw',
    y_data_dict_label='relaxed_data_free_cell_accurate_dftd3bj',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with free cell, no VdW- energy (eV)',
    y_label='Relaxed with free cell and DFT-D3(BJ) VdW - energy (eV)',
    scatter_size_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj',
    scatter_size_data_dict_label='relaxed_data_free_cell_accurate_dftd3bj',
    scatter_size_data_key='cell_corners_msd_to_ref',
    scatter_size_scaling=1000,
    scatter_size_label='cell corners msd to refined (\u212B^2)',
    scatter_color_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj',
    scatter_color_data_dict_label='relaxed_data_free_cell_accurate_dftd3bj',
    scatter_color_data_key='cell_size_disto_to_ref',
    scatter_color_label='cell_size_disto_to_ref (%)',
    markersize=2,
    title=('Energies and cell deviation to refined\n'
           'with DFT-D3(BJ) and without VdW correction'),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.2,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)


fig30, ax30 = plt.subplots(2, 1)
mapping = {
    'fixed-refined-cell, no-VdW': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_novdw',
        'dict_label': 'relaxed_data_fixed_cell_accurate_novdw',
    },
    'fixed-refined-cell, DFT-D2': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate',
        'dict_label': 'relaxed_data_fixed_cell_accurate',
    },
    'fixed-refined-cell, DFT-D3(zero)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3z',
        'dict_label': 'relaxed_data_fixed_cell_accurate_dftd3z',
    },
    'fixed-refined-cell, DFT-D3(BJ)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_refined_fixed_cell_accurate_dftd3bj',
        'dict_label': 'relaxed_data_fixed_cell_accurate_dftd3bj',
    },
    'free-cell, no-VdW': {
        'group': 'AsTe3_Te-based_sc181_relaxed_free_cell_accurate_novdw',
        'dict_label': 'relaxed_data_free_cell_accurate_novdw',
    },
    'free-cell, DFT-D2': {
        'group': 'AsTe3_Te-based_sc181_relaxed_free_cell_accurate',
        'dict_label': 'relaxed_data_free_cell_accurate',
    },
    'free-cell, DFT-D3(zero)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3z',
        'dict_label': 'relaxed_data_free_cell_accurate_dftd3z',
    },
    'free-cell, DFT-D3(BJ)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj',
        'dict_label': 'relaxed_data_free_cell_accurate_dftd3bj',
    },
    'free-cell, PBE0 + DFT-D3(BJ)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_free_cell_accurate_pbe0_dftd3bj',
        'dict_label': 'relaxed_data_free_cell_accurate_pbe0_dftd3bj',
    },
    'free-cell, B3LYP + DFT-D3(BJ)': {
        'group': 'AsTe3_Te-based_sc181_relaxed_free_cell_accurate_b3lyp_dftd3bj',
        'dict_label': 'relaxed_data_free_cell_accurate_b3lyp_dftd3bj',
    },
}
lgd = [[], []]
markers = ['o', 's', 'v', 'h', 'D', '*', '^', 'p', 'd']
marker_index = 0
for setting in mapping.keys():
    if 'no-VdW' not in setting:
        marker = markers[marker_index]
        marker_index += 1
        if 'fixed-refined-cell' in setting:
            x_key = 'fixed-refined-cell, no-VdW'
            subplot_index = 0
        elif 'free-cell' in setting:
            x_key = 'free-cell, no-VdW'
            subplot_index = 1
        _fig, _ax = pu.plot_relaxed_energies_from_data_Dicts(
            x_data_group=mapping[x_key]['group'],
            x_data_dict_label=mapping[x_key]['dict_label'],
            x_data_key='relaxed_energies', y_data_key='relaxed_energies',
            x_label='Relaxation without VdW - energy (eV)',
            y_data_group=mapping[setting]['group'],
            y_data_dict_label=mapping[setting]['dict_label'],
            y_label='Relaxation with {} - energy (eV)'.format(
                setting),
            title=('Energies with and without {} VdW correction\n'
                   'with fixed-refined and free cell.').format(setting),
            nd_experimental_file=experimental_neutron_file,
            nd_experimental_title=experimental_neutron_title,
            nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
            xrd_experimental_file=experimental_xrd_file,
            xrd_experimental_title=experimental_xrd_title,
            xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
            total_pdf_experimental_file=experimental_pdf_file,
            total_pdf_experimental_title=experimental_pdf_title,
            total_pdf_sigma=0.1,
            verbosity=verbosity,
            show_nd=True, show_xrd=True, show_total_pdf=True,
        )

        lgd[subplot_index].append(setting)
        ax30[subplot_index].plot(_ax.lines[0].get_xdata(),
                  _ax.lines[0].get_ydata() - min(_ax.lines[0].get_ydata()),
                  linestyle='none', marker=marker, markersize=4, fillstyle='none')
        plt.close(_fig)

for subplot_index in range(2):
    ax30[subplot_index].set_xlabel('Energy with PBE and no vdW correction (eV)')
    ax30[subplot_index].set_ylabel('E - min(E) with VdW correction (eV)')
    if 'fixed-refined-cell' in setting:
        title = ('Effects of functional and vdW corrections on relaxed energies\n'
                 'with fixed-refined-cell parameters')
    elif 'free-cell' in setting:
        title = ('Effects of functional and vdW corrections on relaxed energies\n'
                 'with free-cell parameters')
    ax30[subplot_index].set_title(title)
    ax30[subplot_index].legend(lgd[subplot_index], bbox_to_anchor=(1.05, 1.0), loc='upper left')
fig30.tight_layout()

# Compare 2 vdW corrections and their effects on cell distortion
fig21, ax21 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3z',
    y_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj',
    x_data_dict_label='relaxed_data_free_cell_accurate_dftd3z',
    y_data_dict_label='relaxed_data_free_cell_accurate_dftd3bj',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with free cell and DFT-D3(zero) vdW - energy (eV)',
    y_label='Relaxed with free cell and DFT-D3(BJ) vdW - energy (eV)',
    scatter_size_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3z',
    scatter_size_data_dict_label='relaxed_data_free_cell_accurate_dftd3z',
    scatter_size_data_key='cell_corners_msd_to_ref',
    scatter_size_scaling=1000,
    scatter_size_label='cell corners msd to refined with DFT-D3(zero) (\u212B^2)',
    scatter_color_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj',
    scatter_color_data_dict_label='relaxed_data_free_cell_accurate_dftd3bj',
    scatter_color_data_key='cell_corners_msd_to_ref',
    scatter_color_label='cell corners msd to refined with DFT-D3(BJ) (\u212B^2)',
    title=('Comparisons of DFT-D3 vand der Waals corrections with BJ and zero damping\n'
           'on free-cell relaxed energies and cell deviation to refined'),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.2,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Compare PBE-no-vdW to PBE0+DFT-D3(BJ)
fig22, ax22 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_novdw',
    y_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_pbe0_dftd3bj',
    x_data_dict_label='relaxed_data_free_cell_accurate_novdw',
    y_data_dict_label='relaxed_data_free_cell_accurate_pbe0_dftd3bj',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with free cell and PBE - energy (eV)',
    y_label='Relaxed with free cell and PBE0 + DFT-D3(BJ) - energy (eV)',
    scatter_size_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_pbe0_dftd3bj',
    scatter_size_data_dict_label='relaxed_data_free_cell_accurate_pbe0_dftd3bj',
    scatter_size_data_key='cell_corners_msd_to_ref',
    scatter_size_scaling=1000,
    scatter_size_label='cell corners msd to refined with PBE0 + DFT-D3(BJ) (\u212B^2)',
    scatter_color_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_pbe0_dftd3bj',
    scatter_color_data_dict_label='relaxed_data_free_cell_accurate_pbe0_dftd3bj',
    scatter_color_data_key='cell_corners_msd_to_ref',
    scatter_color_label='cell corners msd to refined with PBE0 + DFT-D3(BJ) (\u212B^2)',
    title=('Comparisons of PBE and PBE0 + DFT-D3(BJ)\n'
           'relaxed energies and cell deviation to refined'),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.2,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Compare PBE-no-vdW to B3LYP+DFT-D3(BJ)
fig23, ax23 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_novdw',
    y_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_b3lyp_dftd3bj',
    x_data_dict_label='relaxed_data_free_cell_accurate_novdw',
    y_data_dict_label='relaxed_data_free_cell_accurate_b3lyp_dftd3bj',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with free cell and PBE - energy (eV)',
    y_label='Relaxed with free cell and B3LYP + DFT-D3(BJ) - energy (eV)',
    scatter_size_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_b3lyp_dftd3bj',
    scatter_size_data_dict_label='relaxed_data_free_cell_accurate_b3lyp_dftd3bj',
    scatter_size_data_key='cell_corners_msd_to_ref',
    scatter_size_scaling=1000,
    scatter_size_label='cell corners msd to refined with B3LYP + DFT-D3(BJ) (\u212B^2)',
    scatter_color_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_b3lyp_dftd3bj',
    scatter_color_data_dict_label='relaxed_data_free_cell_accurate_b3lyp_dftd3bj',
    scatter_color_data_key='cell_corners_msd_to_ref',
    scatter_color_label='cell corners msd to refined with B3LYP + DFT-D3(BJ) (\u212B^2)',
    title=('Comparisons of PBE and B3LYP + DFT-D3(BJ)\n'
           'relaxed energies and cell deviation to refined'),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.2,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

# Compare PBE+DFT-D3(BJ) to B3LYP+DFT-D3(BJ)
fig24, ax24 = pu.plot_relaxed_energies_from_data_Dicts(
    x_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_dftd3bj',
    y_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_b3lyp_dftd3bj',
    x_data_dict_label='relaxed_data_free_cell_accurate_dftd3bj',
    y_data_dict_label='relaxed_data_free_cell_accurate_b3lyp_dftd3bj',
    x_data_key='relaxed_energies', y_data_key='relaxed_energies',
    x_label='Relaxed with free cell and PBE + DFT-D3(BJ) - energy (eV)',
    y_label='Relaxed with free cell and B3LYP + DFT-D3(BJ) - energy (eV)',
    scatter_size_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_b3lyp_dftd3bj',
    scatter_size_data_dict_label='relaxed_data_free_cell_accurate_b3lyp_dftd3bj',
    scatter_size_data_key='cell_corners_msd_to_ref',
    scatter_size_scaling=1000,
    scatter_size_label='cell corners msd to refined with B3LYP + DFT-D3(BJ) (\u212B^2)',
    scatter_color_data_group='AsTe3_Te-based_sc181_relaxed_free_cell_accurate_b3lyp_dftd3bj',
    scatter_color_data_dict_label='relaxed_data_free_cell_accurate_b3lyp_dftd3bj',
    scatter_color_data_key='xray_pdf_rmsd_opt_sigma',
    scatter_color_label='RMSD to PDF with B3LYP + DFT-D3(BJ) (\u212B^2)',
    title=('Comparisons of PBE+DFT-D3(BJ) and B3LYP+DFT-D3(BJ)\n'
           'relaxed energies and cell deviation to refined'),
    nd_experimental_file=experimental_neutron_file,
    nd_experimental_title=experimental_neutron_title,
    nd_two_theta_range=(20, 120), nd_fwhm=0.5, nd_eta=0.33,
    xrd_experimental_file=experimental_xrd_file,
    xrd_experimental_title=experimental_xrd_title,
    xrd_two_theta_range=(10, 80), xrd_fwhm=0.2, xrd_eta=0.33,
    total_pdf_experimental_file=experimental_pdf_file,
    total_pdf_experimental_title=experimental_pdf_title,
    total_pdf_sigma=0.2,
    verbosity=verbosity,
    show_nd=True, show_xrd=True, show_total_pdf=True
)

plt.show()

# end of script plot_multi_2021-10-18.py
