#!/usr/local/miniconda/envs/aiida-1.6.8/bin/python3

from aiida.common import AttributeDict
from aiida.orm import Code, Dict
from aiida import load_profile

import project_utils as pu

load_profile()

# main
if __name__ == '__main__':

    # USER PARAMETERS
    DRY_RUN = False
    TEST_MODE = False

    data_dict = pu.get_vasp_code_and_computer_data(computer_label='jean-zay',
                                                   test_mode=TEST_MODE)

    if TEST_MODE:
        RELAX_SETTING = 'test'
        VERBOSITY=2
    else:
        RELAX_SETTING = 'free_cell_accurate_dftd3z'
        VERBOSITY=1

    RELAX_PARAM_FILE=pu.get_relax_param_file(RELAX_SETTING,
                                             verbosity=VERBOSITY)

    MAX_NB_OF_RELAX_JOBS = 30

    INITIAL_STRUCT_GROUP_NAME = \
        'AsTe3_Te-based_sc181_relaxed_free_cell_accurate'
    PREVIOUS_RELAX_SETTING = 'free_cell_accurate'

    if TEST_MODE:
        NB_OF_STRUCTURES = 2
    else:
        NB_OF_STRUCTURES = 100

    pu.prepare_and_submit_relax(relax_code=data_dict['code'],
        relax_potential_family=data_dict['potential_family'],
        relax_potential_mapping=data_dict['potential_mapping'],
        relax_options=data_dict['options'],
        relax_param_file=RELAX_PARAM_FILE,
        max_nb_of_relax_jobs=MAX_NB_OF_RELAX_JOBS,
        initial_struct_group_name=INITIAL_STRUCT_GROUP_NAME,
        nb_of_structures=NB_OF_STRUCTURES,
        previous_relax_setting=PREVIOUS_RELAX_SETTING,
        relax_setting=RELAX_SETTING,
        dry_run=DRY_RUN, verbosity=VERBOSITY)

