"""
Prepare and submit relaxations with 'rough_fixed_cell' setting

Input structuyres are picked among As/Te configurations generated with supercell, ranked by ilowest-Coulomb-energy of Te(0)/Te(2-)/As(3+) repartitions, and stored in group:

AsTe3_Te-based_sc181_As-Te-configurations_no-opt
"""

from aiida.common import AttributeDict
from aiida.orm import Code
from aiida import load_profile

import os
import project_utils as pu

load_profile()

# main
if __name__ == '__main__':

    # TODO : the following user inputs should be defined outside the function
    RELAX_POTENTIAL_FAMILY = 'PBE.54'
    RELAX_POTENTIAL_MAPPING = {'Te': 'Te', 'As': 'As'}
    RELAX_OPTIONS = AttributeDict()
    """ Curta setting
    RELAX_CODE_STRING = 'vasp-5.4.4@curta'
    RELAX_OPTIONS.account = ''
    RELAX_OPTIONS.qos = ''
    RELAX_OPTIONS.resources = {'num_machines': 1,
                               'num_mpiprocs_per_machine': 32}
    RELAX_OPTIONS.queue_name = 'visu'
    """

    """ Jean-Zay (write-on-scratch) setting """
    RELAX_CODE_STRING = 'vasp-5.4.4@jean-zay'
    RELAX_OPTIONS.account = 'def@cpu'
    # Quality-of-service : On Jean-Zay, use :
    #   - 'qos_cpu-dev' for jobs requiring less than 2 hours (WARNING: 10 JOBS MAX)
    #   - 'qos_cpu-t4' for jobs requiring more than 20 hours
    #   - 'qos_cpu-t3' for standard jobs between 2 and 20 hours
    # RELAX_OPTIONS.qos = 'qos_cpu-dev'  # WARNING: 10 JOBS MAX
    RELAX_OPTIONS.qos = 'qos_cpu-t3'
    RELAX_OPTIONS.resources = {'num_machines': 1,
                               'num_mpiprocs_per_machine': 40}
    RELAX_OPTIONS.queue_name = ''

    RELAX_OPTIONS.max_wallclock_seconds = 2 * 60 * 60
    # RELAX_OPTIONS.max_memory_kb = 10240000

    RELAX_CODE = Code.get_from_string(RELAX_CODE_STRING)

    # Specify csv file containing the multi-step relaxation parameters
    """
    RELAX_PARAM_FILE = os.path.join(os.getcwd(),'relax_param_files',
                                    'multistep_input_param_test.csv')
    """
    RELAX_PARAM_FILE = os.path.join(os.getcwd(),'relax_param_files',
                                    'multistep_input_param_fixed-cell-rough.csv')
    # RELAX_SETTING_LABEL = 'fixed_cell_rough'  # Not needed: this is the default

    MAX_NB_OF_RELAX_JOBS = 30  # Set to 10 if RELAX_OPTIONS.qos = 'qos_cpu-dev'
    # SUPERCELL_STRUCT_GROUP_NAME = 'test_group'
    SUPERCELL_STRUCT_GROUP_NAME = 'AsTe3_Te-based_sc181_As-Te-configurations_no-opt'
    LOWEST_E_C_DATA_LABEL='lowest_E_C_data'

    NB_OF_LOWEST_E_C_STRUCTS = 1200
    NB_OF_RANDOM_STRUCTS = 1200
    NB_OF_HIGHEST_E_C_STRUCTS = 100

    pu.prepare_and_submit_rough_fixed_cell_relax(RELAX_CODE,
        RELAX_POTENTIAL_FAMILY, RELAX_POTENTIAL_MAPPING, RELAX_OPTIONS,
        RELAX_PARAM_FILE, MAX_NB_OF_RELAX_JOBS, NB_OF_LOWEST_E_C_STRUCTS,
        NB_OF_RANDOM_STRUCTS, NB_OF_HIGHEST_E_C_STRUCTS,
        supercell_struct_group_name=SUPERCELL_STRUCT_GROUP_NAME,
        lowest_E_C_data_label=LOWEST_E_C_DATA_LABEL,
        dry_run=False)


